from setuptools import setup, find_packages

setup(
    name='SajadKM',
    version='0.1',
    packages=find_packages(),
    author='Sajad @K_D_QQ',
    author_email='lahauiva@gmail.com',
    description='TOOC',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ]
)
